Code Documentation
==================
pwbs
----
.. automodule:: pwbs
   :members:

pwbs.api
--------
.. automodule:: pwbs.api
    :members:

pwbs.command
------------
.. automodule:: pwbs.command
    :members:

pwbs.command.command
~~~~~~~~~~~~~~~~~~~~
.. automodule:: pwbs.command.command
    :members:

pwbs.config
-----------
.. automodule:: pwbs.config
    :members:

pwbs.config.config_manager
~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: pwbs.config.config_manager
    :members:

pwbs.config.pwbs_config
~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: pwbs.config.pwbs_config
    :members:

pwbs.core
---------
.. automodule:: pwbs.core
    :members:

pwbs.lib
--------
.. automodule:: pwbs.lib
    :members:

pwbs.lib.pwm
~~~~~~~~~~~~

pwbs.lib.pwm - README
~~~~~~~~~~~~~~~~~~~~~

.. include:: ../../pwbs/lib/pwm/README.rst

pwbs.lib.pwm - HISTORY
~~~~~~~~~~~~~~~~~~~~~~

.. include:: ../../pwbs/lib/pwm/HISTORY.rst

pwbs.lib.pwm - Documentation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pwbs.lib.pwm
    :members:

.. automodule:: pwbs.lib.pwm.pwm_debug
    :members:

.. automodule:: pwbs.lib.pwm.pwm_exec
    :members:

.. automodule:: pwbs.lib.pwm.pwm_json
    :members:

.. automodule:: pwbs.lib.pwm.pwm_system
    :members:

.. automodule:: pwbs.lib.pwm.pwm_watcher
    :members:


pwbs.log
--------
.. automodule:: pwbs.log
    :members:

pwm.log.logger
~~~~~~~~~~~~~~

.. automodule:: pwbs.log.logger

pwbs.tests
----------
.. automodule:: pwbs.tests
    :members:

pwbs.tests.test_XXXXXX
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pwbs.tests.test_0
    :members:

.. automodule:: pwbs.tests.test_1
    :members:

.. automodule:: pwbs.tests.test_2
    :members:

.. automodule:: pwbs.tests.test_3
    :members:

>> Test 4 Deleted

.. automodule:: pwbs.tests.test_5
    :members:
